import { 
  select, 
  extent,
  axisLeft,
  axisBottom,
  scaleLinear
} from 'd3';

export const scatterplot = (selection, props) => {
  const {
    width,
    height,
		circleRadius,
    margin,
    color,
    cValue,
    selectedlegend,
    data
  } = props;
  
  const title = 'High-technology exports vs Taxes on international trade';

  var xValue = d => data['High-technology exports (% of manufactured exports)'];
  const xAxisLabel = 'High-technology exports (% of manufactured exports)';
  
  var yValue = d => data['Taxes on international trade (% of revenue)'];
//  const circleRadius = 8;
  const yAxisLabel = 'Taxes on international trade (% of revenue)';
 
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();

  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(10);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const g = selection.selectAll('.container').data([null]);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -50)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 55)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  const points = g.selectAll('circle').data(data);
  const pointsEnter = points.enter().append('circle')
    
  pointsEnter
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius)
  	  .style('fill', d => color(cValue(d)));
  
  points.merge(points)
      .attr('opacity', d =>
        (!selectedLegend || d === selectedLegend) 
            ? 1 
            : 0.05
      );
  
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
  
};